pub struct AddCronTransactionV0 {
pub payer: Pubkey,
pub authority: Pubkey,
pub cron_job: Pubkey,
pub cron_job_transaction: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for AddCronTransactionV0.
Fields
payer: Pubkeycron_job: Pubkeycron_job_transaction: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AddCronTransactionV0where
Pubkey: BorshSerialize,
impl BorshSerialize for AddCronTransactionV0where
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AddCronTransactionV0
impl ToAccountMetas for AddCronTransactionV0
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AddCronTransactionV0
impl RefUnwindSafe for AddCronTransactionV0
impl Send for AddCronTransactionV0
impl Sync for AddCronTransactionV0
impl Unpin for AddCronTransactionV0
impl UnwindSafe for AddCronTransactionV0