pub struct RequeueCronTaskV0 {
pub payer: Pubkey,
pub authority: Pubkey,
pub queue_authority: Pubkey,
pub task_queue_authority: Pubkey,
pub cron_job: Pubkey,
pub task_queue: Pubkey,
pub task: Pubkey,
pub task_return_account_1: Pubkey,
pub task_return_account_2: Pubkey,
pub system_program: Pubkey,
pub tuktuk_program: Pubkey,
}Expand description
Generated client accounts for RequeueCronTaskV0.
Fields
payer: Pubkeycron_job: Pubkeytask_queue: Pubkeytask: Pubkeytask_return_account_1: Pubkeytask_return_account_2: Pubkeysystem_program: Pubkeytuktuk_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for RequeueCronTaskV0where
Pubkey: BorshSerialize,
impl BorshSerialize for RequeueCronTaskV0where
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for RequeueCronTaskV0
impl ToAccountMetas for RequeueCronTaskV0
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for RequeueCronTaskV0
impl RefUnwindSafe for RequeueCronTaskV0
impl Send for RequeueCronTaskV0
impl Sync for RequeueCronTaskV0
impl Unpin for RequeueCronTaskV0
impl UnwindSafe for RequeueCronTaskV0