pub struct RemoveCronTransactionV0 {
pub args: RemoveCronTransactionArgsV0,
}Expand description
Instruction argument
Fields
args: RemoveCronTransactionArgsV0Trait Implementations
Sourceimpl BorshDeserialize for RemoveCronTransactionV0
impl BorshDeserialize for RemoveCronTransactionV0
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for RemoveCronTransactionV0
impl Discriminator for RemoveCronTransactionV0
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more