pub struct RequeueCronTaskV0 {
pub args: RequeueCronTaskArgsV0,
}Expand description
Instruction argument
Fields
args: RequeueCronTaskArgsV0Trait Implementations
Sourceimpl BorshDeserialize for RequeueCronTaskV0
impl BorshDeserialize for RequeueCronTaskV0
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RequeueCronTaskV0where
RequeueCronTaskArgsV0: BorshSerialize,
impl BorshSerialize for RequeueCronTaskV0where
RequeueCronTaskArgsV0: BorshSerialize,
Sourceimpl Discriminator for RequeueCronTaskV0
impl Discriminator for RequeueCronTaskV0
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for RequeueCronTaskV0
impl InstructionData for RequeueCronTaskV0