pub struct RemoteTaskTransactionV0 {
pub verification_hash: [u8; 32],
pub transaction: CompiledTransactionV0,
}Fields
verification_hash: [u8; 32]transaction: CompiledTransactionV0Trait Implementations
Sourceimpl AccountDeserialize for RemoteTaskTransactionV0
impl AccountDeserialize for RemoteTaskTransactionV0
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl BorshDeserialize for RemoteTaskTransactionV0
impl BorshDeserialize for RemoteTaskTransactionV0
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for RemoteTaskTransactionV0
impl Clone for RemoteTaskTransactionV0
Sourcefn clone(&self) -> RemoteTaskTransactionV0
fn clone(&self) -> RemoteTaskTransactionV0
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteTaskTransactionV0
impl Debug for RemoteTaskTransactionV0
Sourceimpl Default for RemoteTaskTransactionV0
impl Default for RemoteTaskTransactionV0
Sourcefn default() -> RemoteTaskTransactionV0
fn default() -> RemoteTaskTransactionV0
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for RemoteTaskTransactionV0
impl Discriminator for RemoteTaskTransactionV0
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more