pub struct CloseTaskQueueV0 {
pub rent_refund: Pubkey,
pub payer: Pubkey,
pub update_authority: Pubkey,
pub tuktuk_config: Pubkey,
pub task_queue: Pubkey,
pub task_queue_name_mapping: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for CloseTaskQueueV0.
Fields
rent_refund: Pubkeypayer: Pubkeytuktuk_config: Pubkeytask_queue: Pubkeytask_queue_name_mapping: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for CloseTaskQueueV0where
Pubkey: BorshSerialize,
impl BorshSerialize for CloseTaskQueueV0where
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for CloseTaskQueueV0
impl ToAccountMetas for CloseTaskQueueV0
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CloseTaskQueueV0
impl RefUnwindSafe for CloseTaskQueueV0
impl Send for CloseTaskQueueV0
impl Sync for CloseTaskQueueV0
impl Unpin for CloseTaskQueueV0
impl UnwindSafe for CloseTaskQueueV0