pub struct DequeueTaskV0 {
pub queue_authority: Pubkey,
pub rent_refund: Pubkey,
pub task_queue_authority: Pubkey,
pub task_queue: Pubkey,
pub task: Pubkey,
}Expand description
Generated client accounts for DequeueTaskV0.
Fields
rent_refund: Pubkeytask_queue: Pubkeytask: PubkeyTrait Implementations
Sourceimpl BorshSerialize for DequeueTaskV0where
Pubkey: BorshSerialize,
impl BorshSerialize for DequeueTaskV0where
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for DequeueTaskV0
impl ToAccountMetas for DequeueTaskV0
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for DequeueTaskV0
impl RefUnwindSafe for DequeueTaskV0
impl Send for DequeueTaskV0
impl Sync for DequeueTaskV0
impl Unpin for DequeueTaskV0
impl UnwindSafe for DequeueTaskV0