pub struct QueueTaskV0 {
pub payer: Pubkey,
pub queue_authority: Pubkey,
pub task_queue_authority: Pubkey,
pub task_queue: Pubkey,
pub task: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for QueueTaskV0.
Fields
payer: Pubkeytask_queue: Pubkeytask: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for QueueTaskV0where
Pubkey: BorshSerialize,
impl BorshSerialize for QueueTaskV0where
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for QueueTaskV0
impl ToAccountMetas for QueueTaskV0
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for QueueTaskV0
impl RefUnwindSafe for QueueTaskV0
impl Send for QueueTaskV0
impl Sync for QueueTaskV0
impl Unpin for QueueTaskV0
impl UnwindSafe for QueueTaskV0