pub struct UpdateTaskQueueV0 {
pub payer: Pubkey,
pub update_authority: Pubkey,
pub task_queue: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for UpdateTaskQueueV0.
Fields
payer: Pubkeytask_queue: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateTaskQueueV0where
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateTaskQueueV0where
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateTaskQueueV0
impl ToAccountMetas for UpdateTaskQueueV0
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateTaskQueueV0
impl RefUnwindSafe for UpdateTaskQueueV0
impl Send for UpdateTaskQueueV0
impl Sync for UpdateTaskQueueV0
impl Unpin for UpdateTaskQueueV0
impl UnwindSafe for UpdateTaskQueueV0