pub struct RunTaskV0 {
pub args: RunTaskArgsV0,
}Expand description
Instruction argument
Fields
args: RunTaskArgsV0Trait Implementations
Sourceimpl BorshDeserialize for RunTaskV0where
RunTaskArgsV0: BorshDeserialize,
impl BorshDeserialize for RunTaskV0where
RunTaskArgsV0: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RunTaskV0where
RunTaskArgsV0: BorshSerialize,
impl BorshSerialize for RunTaskV0where
RunTaskArgsV0: BorshSerialize,
Sourceimpl Discriminator for RunTaskV0
impl Discriminator for RunTaskV0
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for RunTaskV0
impl InstructionData for RunTaskV0