pub struct UpdateTaskQueueV0 {
pub args: UpdateTaskQueueArgsV0,
}Expand description
Instruction argument
Fields
args: UpdateTaskQueueArgsV0Trait Implementations
Sourceimpl BorshDeserialize for UpdateTaskQueueV0
impl BorshDeserialize for UpdateTaskQueueV0
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateTaskQueueV0where
UpdateTaskQueueArgsV0: BorshSerialize,
impl BorshSerialize for UpdateTaskQueueV0where
UpdateTaskQueueArgsV0: BorshSerialize,
Sourceimpl Discriminator for UpdateTaskQueueV0
impl Discriminator for UpdateTaskQueueV0
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateTaskQueueV0
impl InstructionData for UpdateTaskQueueV0