pub struct QueueTaskArgsV0 {
pub id: u16,
pub trigger: TriggerV0,
pub transaction: TransactionSourceV0,
pub crank_reward: Option<u64>,
pub free_tasks: u8,
pub description: String,
}Fields
id: u16trigger: TriggerV0transaction: TransactionSourceV0crank_reward: Option<u64>free_tasks: u8description: StringTrait Implementations
Sourceimpl BorshDeserialize for QueueTaskArgsV0
impl BorshDeserialize for QueueTaskArgsV0
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for QueueTaskArgsV0
impl BorshSerialize for QueueTaskArgsV0
Sourceimpl Clone for QueueTaskArgsV0
impl Clone for QueueTaskArgsV0
Sourcefn clone(&self) -> QueueTaskArgsV0
fn clone(&self) -> QueueTaskArgsV0
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for QueueTaskArgsV0
impl RefUnwindSafe for QueueTaskArgsV0
impl Send for QueueTaskArgsV0
impl Sync for QueueTaskArgsV0
impl Unpin for QueueTaskArgsV0
impl UnwindSafe for QueueTaskArgsV0