pub struct RunTaskArgsV0 {
pub free_task_ids: Vec<u16>,
}Fields
free_task_ids: Vec<u16>Trait Implementations
Sourceimpl BorshDeserialize for RunTaskArgsV0
impl BorshDeserialize for RunTaskArgsV0
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RunTaskArgsV0
impl BorshSerialize for RunTaskArgsV0
Sourceimpl Clone for RunTaskArgsV0
impl Clone for RunTaskArgsV0
Sourcefn clone(&self) -> RunTaskArgsV0
fn clone(&self) -> RunTaskArgsV0
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RunTaskArgsV0
impl Debug for RunTaskArgsV0
Sourceimpl Default for RunTaskArgsV0
impl Default for RunTaskArgsV0
Sourcefn default() -> RunTaskArgsV0
fn default() -> RunTaskArgsV0
Returns the “default value” for a type. Read more