pub struct UpdateTaskQueueArgsV0 {
pub min_crank_reward: Option<u64>,
pub capacity: Option<u16>,
pub lookup_tables: Option<Vec<Pubkey>>,
pub update_authority: Option<Pubkey>,
pub stale_task_age: Option<u32>,
}Fields
min_crank_reward: Option<u64>capacity: Option<u16>lookup_tables: Option<Vec<Pubkey>>stale_task_age: Option<u32>Trait Implementations
Sourceimpl BorshDeserialize for UpdateTaskQueueArgsV0where
Option<u64>: BorshDeserialize,
Option<u16>: BorshDeserialize,
Option<Vec<Pubkey>>: BorshDeserialize,
Option<Pubkey>: BorshDeserialize,
Option<u32>: BorshDeserialize,
impl BorshDeserialize for UpdateTaskQueueArgsV0where
Option<u64>: BorshDeserialize,
Option<u16>: BorshDeserialize,
Option<Vec<Pubkey>>: BorshDeserialize,
Option<Pubkey>: BorshDeserialize,
Option<u32>: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateTaskQueueArgsV0where
Option<u64>: BorshSerialize,
Option<u16>: BorshSerialize,
Option<Vec<Pubkey>>: BorshSerialize,
Option<Pubkey>: BorshSerialize,
Option<u32>: BorshSerialize,
impl BorshSerialize for UpdateTaskQueueArgsV0where
Option<u64>: BorshSerialize,
Option<u16>: BorshSerialize,
Option<Vec<Pubkey>>: BorshSerialize,
Option<Pubkey>: BorshSerialize,
Option<u32>: BorshSerialize,
Sourceimpl Clone for UpdateTaskQueueArgsV0
impl Clone for UpdateTaskQueueArgsV0
Sourcefn clone(&self) -> UpdateTaskQueueArgsV0
fn clone(&self) -> UpdateTaskQueueArgsV0
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateTaskQueueArgsV0
impl Debug for UpdateTaskQueueArgsV0
Sourceimpl Default for UpdateTaskQueueArgsV0
impl Default for UpdateTaskQueueArgsV0
Sourcefn default() -> UpdateTaskQueueArgsV0
fn default() -> UpdateTaskQueueArgsV0
Returns the “default value” for a type. Read more